==> qore-0.9.6.tar.bz2: qore-0.9.6/docs/modules/RestClient/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore RestClient Module Reference", "index.html", [
    [ "RestClient Module", "index.html", [
      [ "RestClient Introduction", "index.html#restclientintro", null ],
      [ "Release Notes", "index.html#restclientrelnotes", [
        [ "RestClient v1.7.1", "index.html#restclientv1_7_1", null ],
        [ "RestClient v1.7", "index.html#restclientv1_7", null ],
        [ "RestClient v1.6.1", "index.html#restclientv1_6_1", null ],
        [ "RestClient v1.6", "index.html#restclientv1_6", null ],
        [ "RestClient v1.5", "index.html#restclientv1_5", null ],
        [ "RestClient v1.4.2", "index.html#restclientv1_4_2", null ],
        [ "RestClient v1.4.1", "index.html#restclientv1_4_1", null ],
        [ "RestClient v1.4", "index.html#restclientv1_4", null ],
        [ "RestClient v1.3.1", "index.html#restclientv1_3_1", null ],
        [ "RestClient v1.3", "index.html#restclientv1_3", null ],
        [ "RestClient v1.2", "index.html#restclientv1_2", null ],
        [ "RestClient v1.1", "index.html#restclientv1_1", null ],
        [ "RestClient v1.0", "index.html#restclientv1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.11.tar.bz2: qore-0.9.11/docs/modules/RestClient/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore RestClient Module Reference", "index.html", [
    [ "RestClient Module", "index.html", [
      [ "RestClient Introduction", "index.html#restclientintro", null ],
      [ "Release Notes", "index.html#restclientrelnotes", [
        [ "RestClient v1.7.3", "index.html#restclientv1_7_3", null ],
        [ "RestClient v1.7.2", "index.html#restclientv1_7_2", null ],
        [ "RestClient v1.7.1", "index.html#restclientv1_7_1", null ],
        [ "RestClient v1.7", "index.html#restclientv1_7", null ],
        [ "RestClient v1.6.1", "index.html#restclientv1_6_1", null ],
        [ "RestClient v1.6", "index.html#restclientv1_6", null ],
        [ "RestClient v1.5", "index.html#restclientv1_5", null ],
        [ "RestClient v1.4.2", "index.html#restclientv1_4_2", null ],
        [ "RestClient v1.4.1", "index.html#restclientv1_4_1", null ],
        [ "RestClient v1.4", "index.html#restclientv1_4", null ],
        [ "RestClient v1.3.1", "index.html#restclientv1_3_1", null ],
        [ "RestClient v1.3", "index.html#restclientv1_3", null ],
        [ "RestClient v1.2", "index.html#restclientv1_2", null ],
        [ "RestClient v1.1", "index.html#restclientv1_1", null ],
        [ "RestClient v1.0", "index.html#restclientv1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
